@@ -27,16 +27,16 @@ class MotionSensor(Thing):
 
         self.motion = Value(False)
         self.add_property(
-        Property(self,
-                 'motion',
-                 self.motion,
-                 metadata={
-                     '@type': 'MotionProperty',
-                     'title': 'Motion detected',
-                     "type": "boolean",
-                     'description': 'Whether ' + name  + ' motion is detected',
-                     'readOnly': True,
-                 }))
+            Property(self,
+                     'motion',
+                     self.motion,
+                     metadata={
+                         '@type': 'MotionProperty',
+                         'title': 'Motion detected',
+                         "type": "boolean",
+                         'description': 'Whether ' + name  + ' motion is detected',
+                         'readOnly': True,
+                     }))
 
         self.last_motion = Value(datetime.now().isoformat())
         self.add_property(
@@ -44,7 +44,7 @@ class MotionSensor(Thing):
                      'motion_last_seen',
                      self.last_motion,
                      metadata={
-                         'title': 'Motion last seen date time',
+                         'title': 'Motion last seen',
                          "type": "string",
                          'unit': 'datetime',
                          'description': 'The ISO 8601 date time of last movement',
@@ -67,9 +67,9 @@ class MotionSensor(Thing):
             self.motion.notify_of_external_update(False)
 
 
-def run_server(hostname, port, gpio_number, name, description):
+def run_server(port, gpio_number, name, description):
     motion_sensor = MotionSensor(gpio_number, name, description)
-    server = WebThingServer(SingleThing(motion_sensor), hostname=hostname, port=port)
+    server = WebThingServer(SingleThing(motion_sensor), port=port, disable_host_validation=True)
     try:
         logging.info('starting the server')
         server.start()
